@@ -25,15 +25,13 @@ GType ephy_session_command_get_type (void);
 #define EPHY_TYPE_NEW_TAB_FLAGS ephy_new_tab_flags_get_type()
 GType ephy_new_tab_flags_get_type (void);
 
-/* --- ephy-tab.h --- */
-#define EPHY_TYPE_TAB_NAVIGATION_FLAGS ephy_tab_navigation_flags_get_type()
-GType ephy_tab_navigation_flags_get_type (void);
-#define EPHY_TYPE_TAB_ADDRESS_EXPIRE ephy_tab_address_expire_get_type()
-GType ephy_tab_address_expire_get_type (void);
-
 /* --- ephy-navigation-action.h --- */
 #define EPHY_TYPE_NAVIGATION_DIRECTION ephy_navigation_direction_get_type()
 GType ephy_navigation_direction_get_type (void);
+
+/* --- pdm-dialog.h --- */
+#define EPHY_TYPE_CLEAR_ALL_DIALOG_FLAGS pdm_clear_all_dialog_flags_get_type()
+GType pdm_clear_all_dialog_flags_get_type (void);
 G_END_DECLS
 
 #endif /* EPHY_TYPE_BUILTINS_H */
